@@ -9,6 +9,8 @@ from hypergol.hypergol_project import HypergolProject
 def create_model_block(className, projectDirectory='.', dryrun=None, force=None,):
     """Generates a Model Block class.
 
+    The file will be located in ``project_name/models/blocks/block_name.py``
+
     Parameters
     ----------
     className : string (CamelCase)
@@ -20,7 +22,7 @@ def create_model_block(className, projectDirectory='.', dryrun=None, force=None,
     content = project.render(
         templateName='model_block.py.j2',
         templateData={'className': className},
-        filePath=Path(projectDirectory, 'models', className.asFileName)
+        filePath=Path(projectDirectory, 'models', 'blocks', className.asFileName)
     )
 
     return project.cli_final_message(creationType='ModelBlock', name=className, content=(content, ))
